@@ -100,7 +100,9 @@
   (if (= (string-length args) 0)
       (ft-display (_ "Incomplete syntax"))
       (apply ft-roster-set-nickname (map sans-surrounding-whitespace
-                                         (string-separate args #\space)))))
+             (split-discarding-char #\space (sans-surrounding-whitespace args)
+                                    list)))))
+
 (add-command! /alias "alias" "/alias buddy nickname" "Set the nickname of a buddy")
 
 (define (subscribe-recv jid)
